@@ -27,9 +27,12 @@ const Gc = imports.gi.Gc;
 const Main = imports.main;
 const Util = imports.util;
 
-const CharacterDialog = new Lang.Class({
+var CharacterDialog = new Lang.Class({
     Name: 'CharacterDialog',
     Extends: Gtk.Dialog,
+    Signals: {
+        'character-copied': { param_types: [ GObject.TYPE_STRING ] }
+    },
     Template: 'resource:///org/gnome/Characters/character.ui',
     InternalChildren: ['main-stack', 'character-stack',
                        'character-label', 'missing-label', 'detail-label',
@@ -65,6 +68,8 @@ const CharacterDialog = new Lang.Class({
 
         this._fontDescription = filtered.fontDescription;
         this._setCharacter(filtered.character);
+
+        this._copyRevealerTimeoutId = 0;
     },
 
     _finishSearch: function(result) {
@@ -150,7 +155,7 @@ const CharacterDialog = new Lang.Class({
                     let result = context.search_finish(res);
                     this._finishSearch(result);
                 } catch (e) {
-                    log("Failed to search related: " + e);
+                    log("Failed to search related: " + e.message);
                 }
             }));
 
@@ -181,6 +186,7 @@ const CharacterDialog = new Lang.Class({
                                               this._clipboardOwnerChanged));
         }
         this._clipboard.set_text(this._character, -1);
+        this.emit('character-copied', this._character);
 
         // Show a feedback message with a revealer.  The message is
         // hidden after 2 seconds, or when another client set a
